# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ inputs, config, pkgs, ... }:
{
  imports = [
      ./hardware-configuration.nix
      ../common.nix
      ../modules
  ];

  jade = {
    flatpak.enable = true;
    desktop = {
      enable = true;
      compositing.enable = true;
      creative.enable = true;
      syncthing.enable = true;
      kdeconnect.enable = true;
      cloud.enable = true;
      social.enable = true;
      gaming.enable = true;
    };
    terminal.enable = true;
    neovim.enable = true;
    zsh.enable = true;
  };

  # monitor control
  services.ddccontrol.enable = true;

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  # latest linux kernel
  boot.kernelPackages = pkgs.linuxPackages_latest;
  boot.initrd.kernelModules = [ "amdgpu" ];

  networking.hostName = "monosodium-glutamate-g";

  services.xserver.layout = "us";
  services.xserver.xkbVariant = "altgr-intl";

  services.openssh.settings.PermitRootLogin = "without-password";

  hardware.bluetooth.enable = true;
  hardware.keyboard.uhk.enable = true;
  hardware.enableRedistributableFirmware = true;

  # missing: menu-qalc picom-jonaburg
  environment.systemPackages = with pkgs; [
    # TODO: clean up.
    nvtop-amd
    libGL
  ];

  environment.pathsToLink = [
    "/share/nix-direnv"
  ];

  services.blueman.enable = true;

  services.gnome.gnome-keyring.enable = true;
  programs.seahorse.enable = true;
  security.pam.services.jade.enableGnomeKeyring = true;

  # Copy the NixOS configuration file and link it from the resulting system
  # (/run/current-system/configuration.nix). This is useful in case you
  # accidentally delete configuration.nix.
  # system.copySystemConfiguration = true;

  # networking.firewall.allowedTCPPorts = [ 4713 ];
  systemd.services."NetworkManager-wait-online".enable = false;
  systemd.tmpfiles.rules = [
    "L+    /opt/rocm/hip   -    -    -     -    ${pkgs.hip}"
  ];
  services.xserver.enable = true;
  services.xserver.videoDrivers = [ "amdgpu" ];


  # release channel
  system.stateVersion = "22.05"; # Did you read the comment?
}



